@@ -4,15 +4,24 @@
 from zope.interface import implements
 from zope.component import getMultiAdapter
 
-from Products.Archetypes import atapi
+from Products.CMFCore.utils import getToolByName
+
+try:
+    from Products.LinguaPlone import public as atapi
+except ImportError:
+    # No multilingual support
+    from Products.Archetypes import atapi
+
+from Products.ATContentTypes.content import base
 from Products.ATContentTypes.content import folder
 from Products.ATContentTypes.content import schemata
 
 from tecnoteca.googlemap import googlemapMessageFactory as _
 from tecnoteca.googlemap.interfaces import ITTGoogleMap
 from tecnoteca.googlemap.config import PROJECTNAME
+from tecnoteca.googlemap.content.ttgooglemapcoordinates import *
 
-TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
+TTGoogleMapSchema = folder.ATFolderSchema.copy() + TTGoogleMapCoordinatesSchema.copy() + atapi.Schema((
 
     # -*- Your Archetypes field definitions here ... -*-
 
@@ -37,8 +46,19 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
         ),
         required=True,
         default_method = 'defaultWidth',
-        validators=('isInt'),
     ),
+    
+                                                                                                       
+    atapi.BooleanField(
+        'FullWidth',
+        storage=atapi.AnnotationStorage(),
+        languageIndependent = True,
+        widget=atapi.BooleanWidget(
+            label=_(u"FullWidth"),
+            description=_(u"Set map to full width (overrides MapWidth)"),
+        ),
+        default=True,
+    ),                                                                                                       
 
 
     atapi.IntegerField(
@@ -51,20 +71,6 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
         ),
         required=True,
         default_method = 'defaultHeight',
-        validators=('isInt'),
-    ),
-
-
-    atapi.TextField(
-        'Coordinates',
-        languageIndependent = True,
-        storage=atapi.AnnotationStorage(),
-        widget=atapi.StringWidget(
-            label=_(u"Coordinates"),
-            description=_(u"Map center coords"),
-            macro='TTGoogleMapCoordinatesWidget',
-        ),
-        required=True,
     ),
 
 
@@ -78,7 +84,6 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
         ),
         required=True,
         default=13,
-        validators=('isInt'),
     ),
 
 
@@ -86,12 +91,15 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
         'MapType',
         storage=atapi.AnnotationStorage(),
         languageIndependent = True,
-        vocabulary = [("G_NORMAL_MAP","Normal"),("G_SATELLITE_MAP","Satellite"),("G_HYBRID_MAP","Hybrid")],
+        vocabulary = [("google.maps.MapTypeId.ROADMAP","Normal"),
+                      ("google.maps.MapTypeId.SATELLITE","Satellite"),
+                      ("google.maps.MapTypeId.HYBRID","Hybrid"),
+                      ("google.maps.MapTypeId.TERRAIN","Terrain")],
         widget=atapi.SelectionWidget(
             label=_(u"Map Type"),
             description=_(u"Select default map type"),
         ),
-        default="G_NORMAL_MAP",
+        default="google.maps.MapTypeId.ROADMAP",
         required=True,
     ),
     
@@ -106,7 +114,6 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
         ),
         required=True,
         default_method = 'defaultCatBoxHeight',
-        validators=('isInt'),
     ),
     
     
@@ -120,7 +127,6 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
         ),
         required=True,
         default_method = 'defaultMarkerBoxHeight',
-        validators=('isInt'),
     ),
     
     
@@ -133,17 +139,57 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
             label=_(u"Panoramio"),
             description=_(u"Show Panoramio button"),
         ),
-        default=True,
+        default=False,
     ),
-
-
+                                                                                                       
+                                                                                                       
+                                                                                                       
     atapi.BooleanField(
-        'LargeMapControl',
+        'Weather',
         storage=atapi.AnnotationStorage(),
         languageIndependent = True,
         widget=atapi.BooleanWidget(
-            label=_(u"Large Map Control"),
-            description=_(u"Large map control buttons"),
+            label=_(u"Weather"),
+            description=_(u"Show weather button"),
+        ),
+        default=False,
+    ),
+                                                                                                       
+                                                                                                       
+                                                                                                       
+    atapi.BooleanField(
+        'Traffic',
+        storage=atapi.AnnotationStorage(),
+        languageIndependent = True,
+        widget=atapi.BooleanWidget(
+            label=_(u"Traffic"),
+            description=_(u"Show traffic button"),
+        ),
+        default=False,
+    ),  
+                                                                                                       
+                                                                                                       
+                                                                                                       
+    atapi.BooleanField(
+        'Bicycle',
+        storage=atapi.AnnotationStorage(),
+        languageIndependent = True,
+        widget=atapi.BooleanWidget(
+            label=_(u"Bicycle"),
+            description=_(u"Show bicycle button"),
+        ),
+        default=False,
+    ),  
+                                                                                                       
+
+
+    atapi.BooleanField(
+        'StreetViewControl',
+        storage=atapi.AnnotationStorage(),
+        languageIndependent = True,
+        widget=atapi.BooleanWidget(
+            label=_(u"Street View Control"),
+            description=_(u"Street view map control button"),
         ),
         default=True,
     ),
@@ -182,6 +228,29 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
         ),
         default=True,
     ),
+    
+    atapi.BooleanField(
+        'Directions',
+        storage=atapi.AnnotationStorage(),
+        languageIndependent = True,
+        widget=atapi.BooleanWidget(
+            label=_(u"Directions"),
+            description=_(u"Show directions"),
+        ),
+        default=True,
+    ),    
+    
+    atapi.StringField(
+        'DefaultMarker',
+        storage=atapi.AnnotationStorage(),
+        default_output_type= 'text/x-html-safe',
+        widget=atapi.SelectionWidget (
+            format="select",
+            label=_(u"Default Marker"),
+            description=_(u"Default marker startup"),
+        ),
+        vocabulary="getMarkersVocabulary",
+    ),
 
 ))
 
@@ -191,6 +260,7 @@ TTGoogleMapSchema = folder.ATFolderSchema.copy() + atapi.Schema((
 TTGoogleMapSchema['title'].storage = atapi.AnnotationStorage()
 TTGoogleMapSchema['description'].storage = atapi.AnnotationStorage()
 
+
 schemata.finalizeATCTSchema(
     TTGoogleMapSchema,
     folderish=True,
@@ -198,7 +268,7 @@ schemata.finalizeATCTSchema(
 )
 
 
-class TTGoogleMap(folder.ATFolder):
+class TTGoogleMap(folder.ATFolder, TTGoogleMapCoordinates):
     """Google Map Object"""
     implements(ITTGoogleMap)
 
@@ -206,17 +276,17 @@ class TTGoogleMap(folder.ATFolder):
     schema = TTGoogleMapSchema
 
     title = atapi.ATFieldProperty('title')
-    description = atapi.ATFieldProperty('description')
+    description = atapi.ATFieldProperty('description')    
 
     # -*- Your ATSchema to Python Property Bridges Here ... -*-
     Text = atapi.ATFieldProperty('Text')
 
     MapWidth = atapi.ATFieldProperty('MapWidth')
+    
+    FullWidth = atapi.ATFieldProperty('FullWidth')
 
     MapHeight = atapi.ATFieldProperty('MapHeight')
 
-    Coordinates = atapi.ATFieldProperty('Coordinates')
-
     ZoomLevel = atapi.ATFieldProperty('ZoomLevel')
 
     MapType = atapi.ATFieldProperty('MapType')
@@ -226,36 +296,33 @@ class TTGoogleMap(folder.ATFolder):
     MarkerBoxHeight = atapi.ATFieldProperty('MarkerBoxHeight')
 
     Panoramio = atapi.ATFieldProperty('Panoramio')
+    
+    Weather = atapi.ATFieldProperty('Weather')
+    
+    Traffic = atapi.ATFieldProperty('Traffic')
+    
+    Bicycle = atapi.ATFieldProperty('Bicycle')    
 
-    LargeMapControl = atapi.ATFieldProperty('LargeMapControl')
+    StreetViewControl = atapi.ATFieldProperty('StreetViewControl')
 
     MapTypeControl = atapi.ATFieldProperty('MapTypeControl')
 
     OverviewMapControl = atapi.ATFieldProperty('OverviewMapControl')
     
-    StartupBoxes = atapi.ATFieldProperty('OpenBoxes')
+    OpenBoxes = atapi.ATFieldProperty('OpenBoxes')
     
-    def getLatitude(self):
-        coordinates = self.getCoordinates().split("|")
-        if(len(coordinates)>1):
-            return coordinates[0]
-        else:
-            return None
+    Directions = atapi.ATFieldProperty('Directions')
     
-    def getLongitude(self):
-        coordinates = self.getCoordinates().split("|")
-        if(len(coordinates)>1):
-            return coordinates[1]
-        else:
-            return None
+    DefaultMarker = atapi.ATFieldProperty('DefaultMarker')
+    
+    def getConfig(self):
+        return getMultiAdapter((self, self.REQUEST), name="ttgooglemap_config")
     
     def defaultWidth(self):
-        config = getMultiAdapter((self, self.REQUEST), name="ttgooglemap_config")
-        return config.default_map_size[1]
+        return self.getConfig().default_map_size[1]
     
     def defaultHeight(self):
-        config = getMultiAdapter((self, self.REQUEST), name="ttgooglemap_config")
-        return config.default_map_size[0]
+        return self.getConfig().default_map_size[0]
     
     def defaultCatBoxHeight(self):
         mapHeight = int(self.defaultHeight())
@@ -265,5 +332,18 @@ class TTGoogleMap(folder.ATFolder):
         mapHeight = int(self.defaultHeight())
         return (mapHeight * 55 / 100) # 55% total map height
     
+    def getMarkersVocabulary(self):
+        vocabulary = atapi.DisplayList()
+        vocabulary.add('','-')
 
-atapi.registerType(TTGoogleMap, PROJECTNAME)
+        for cat in self.getFolderContents(contentFilter={'portal_type':('TTGoogleMapCategory','TTGoogleMapCategoryCT'),'path':{'depth':3, 'query':'/'.join(self.getPhysicalPath()) }}):
+            category = cat.getObject()
+            markers = category.getMarkers()
+            for item in markers:
+                marker = item.getObject()
+                if not marker.isDisabled():
+                    vocabulary.add( str(item.UID), item.pretty_title_or_id())
+        
+        return vocabulary
+
+base.registerATCT(TTGoogleMap, PROJECTNAME)
\ No newline at end of file
