@@ -7,14 +7,17 @@
 ##parameters=categories
 ##title=
 
+newline="\n"
 output=""
 for catloop in categories:
     category = catloop.getObject()
     
     # default active
     if(category.getDefaultActive()):
-        output+="show(\""+category.getUniqueId()+"\");";
+        output+="show(\""+category.UID()+"\");";
     else:
-        output+="hide(\""+category.getUniqueId()+"\");";    
+        output+="hide(\""+category.UID()+"\");";
+        
+    output += newline
         
 return output
\ No newline at end of file
