@@ -7,11 +7,20 @@
 ##parameters=polylines
 ##title=
 
-output=""
+helper = context.restrictedTraverse('@@ttgooglemap_helpersview')
+
+newline="\n"
+output=newline
+
 count=0;
 for polyloop in polylines:    
     polyline = polyloop.getObject()
     count = count+1
+        
+    # info window html
+    html = helper.getTitleHTML(polyline)
+    html += helper.getDescriptionHTML(polyline)
+    html += helper.getRelatedItemsHTML(polyline);
     
     output += "createPolyline("
     output += str(count)
@@ -29,7 +38,9 @@ for polyloop in polylines:
     output += str(polyline.getZoomFactor())
     output += ","
     output += str(polyline.getNumLevels())
+    output += ","
+    output += "\"" + html + "\""    
     output += ");";
-    output += "\n";
+    output += newline;
     
 return output
\ No newline at end of file
